@@ -1,7 +1,9 @@
 import base64
 from enum import Enum
 from typing import Optional
-from .model import TypedModel
+
+from vocode.streaming.models.audio_encoding import AudioEncoding
+from .model import BaseModel, TypedModel
 from .transcriber import TranscriberConfig
 from .agent import AgentConfig
 from .synthesizer import SynthesizerConfig
@@ -13,6 +15,7 @@ class WebSocketMessageType(str, Enum):
     AUDIO = "websocket_audio"
     READY = "websocket_ready"
     STOP = "websocket_stop"
+    AUDIO_CONFIG_START = "websocket_audio_config_start"
 
 
 class WebSocketMessage(TypedModel, type=WebSocketMessageType.BASE):
@@ -37,6 +40,26 @@ class StartMessage(WebSocketMessage, type=WebSocketMessageType.START):
     conversation_id: Optional[str] = None
 
 
+class InputAudioConfig(BaseModel):
+    sampling_rate: int
+    audio_encoding: AudioEncoding
+    chunk_size: int
+    downsampling: Optional[int] = None
+
+
+class OutputAudioConfig(BaseModel):
+    sampling_rate: int
+    audio_encoding: AudioEncoding
+
+
+class AudioConfigStartMessage(
+    WebSocketMessage, type=WebSocketMessageType.AUDIO_CONFIG_START
+):
+    input_audio_config: InputAudioConfig
+    output_audio_config: OutputAudioConfig
+    conversation_id: Optional[str] = None
+
+
 class ReadyMessage(WebSocketMessage, type=WebSocketMessageType.READY):
     pass
 
